@@ -11,11 +11,12 @@ class Model(BaseModel):
     name: str
     version: Optional[str] = "HEAD"
     type: Optional[str] = "classification"
+    location: Optional[str] = "europe-west4"
 
     class Config:
         arbitrary_types_allowed = True
 
-    # _model_exists = root_validator(check_model_exists, allow_reuse=True)
+    _model_exists = root_validator(check_model_exists, allow_reuse=True)
     _get_model_type = root_validator(fetch_model_type, allow_reuse=True)
 
 
