@@ -1,4 +1,4 @@
-from captur_ml_sdk.dtypes.generics import Image, EvaluationMeta, Model
+from captur_ml_sdk.dtypes.generics import Image, EvaluationMeta, EvaluationModel
 from pydantic import BaseModel
 from typing import List, Optional, Dict
 
@@ -6,5 +6,5 @@ from typing import List, Optional, Dict
 class ModelEvaluateRequest(BaseModel):
     data: List[Image]
     meta: Optional[EvaluationMeta] = None
-    models: List[Model]
+    models: List[EvaluationModel]
     mapping: Optional[Dict[str, Dict[str, str]]]
