@@ -10,7 +10,9 @@ from typing import Optional
 class Model(BaseModel):
     endpoint_id: str
     location: Optional[str] = "us-central1"
-    type: str
+    task: Optional[str] = "classification"
+    type: Optional[str] = "automl"
+    serving_input: Optional[str] = "bytes_input"
 
     class Config:
         arbitrary_types_allowed = True
