@@ -6,7 +6,7 @@ class LivePredictEventData(BaseModel):
     request_id: str
     endpoint_id: str
     task_type: str
-    model_type: str
+    model_type: Optional[str] = "automl"
     serving_input: str
     location: str
     image_url: AnyUrl
