@@ -10,6 +10,9 @@ from captur_ml_sdk.dtypes.exceptions import (
     VersionNotFoundError,
     VersionNotLiveError
 )
+from captur_ml_sdk.dtypes.generics import Image
+from pydantic import parse_obj_as
+from typing import List
 
 def get_model_list_from_aiplatform(location: str = "europe-west4"):
     """Returns list of trained models with details"""
@@ -345,3 +348,20 @@ def get_dataset_id_from_model_id(model_name, model_id):
         if version.get("model_id") == model_id:
             dataset_id = version.get("dataset_id")
     return dataset_id
+
+
+def read_image_objs(gs_filepath: str) -> List[Image]:
+    """Read json from GCP Storage and convert to Image objects.
+
+    Args:
+        gs_filepath (str): Location of file in GCP Storage.
+
+    Returns:
+        List[Image]: List of image objects.
+    """
+    img_objs = []
+    gcs_file_system = gcsfs.GCSFileSystem()
+    with gcs_file_system.open(gs_filepath, "r") as f:
+        for line in f:
+            img_objs.append(parse_obj_as(Image, json.loads(line)))
+    return img_objs
